Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(273)

Unified Diff: Source/platform/heap/ThreadState.h

Issue 1162533003: Oilpan: Rename makeConsistentForSweeping to makeConsistentForGC (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/platform/heap/Heap.cpp ('k') | Source/platform/heap/ThreadState.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/platform/heap/ThreadState.h
diff --git a/Source/platform/heap/ThreadState.h b/Source/platform/heap/ThreadState.h
index 3b2c8d649be43b4dc04a4e88083f4b4c0947efe3..c50caa516de3d0c73515aaad5c8992d486a56937 100644
--- a/Source/platform/heap/ThreadState.h
+++ b/Source/platform/heap/ThreadState.h
@@ -332,9 +332,9 @@ public:
// - It is valid that the next GC is scheduled while some thread
// has not yet completed its lazy sweeping of the last GC.
// In this case, the next GC just cancels the remaining lazy sweeping.
// Specifically, preGC() of the next GC calls makeConsistentForSweeping()
// and it marks all not-yet-swept objets as dead.
- void makeConsistentForSweeping();
+ void makeConsistentForGC();
void preGC();
void postGC(GCType);
void preSweep();
@@ -332,9 +332,9 @@ public:
// has not yet completed its lazy sweeping of the last GC.
// In this case, the next GC just cancels the remaining lazy sweeping.
- // Specifically, preGC() of the next GC calls makeConsistentForSweeping()
+ // Specifically, preGC() of the next GC calls makeConsistentForGC()
// and it marks all not-yet-swept objets as dead.
« no previous file with comments | « Source/platform/heap/Heap.cpp ('k') | Source/platform/heap/ThreadState.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698